# Algo Trading Utils

[![CI](https://github.com/Algo-Trading-Tools/algo-trading-utils/actions/workflows/ci.yaml/badge.svg)](https://github.com/Algo-Trading-Tools/algo-trading-utils/actions/workflows/ci.yaml)


A library full of utilities for algorithmic trading and data analysis.